Module: Google::Cloud::NetworkManagement
- Defined in:
- lib/google/cloud/network_management.rb,
lib/google/cloud/network_management/version.rb
Constant Summary collapse
- VERSION =
"2.3.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.network_management| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-network_management library.
-
.organization_vpc_flow_logs_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for OrganizationVpcFlowLogsService.
-
.organization_vpc_flow_logs_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the OrganizationVpcFlowLogsService service is supported by the current client.
-
.reachability_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ReachabilityService.
-
.reachability_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ReachabilityService service is supported by the current client.
-
.vpc_flow_logs_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for VpcFlowLogsService.
-
.vpc_flow_logs_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the VpcFlowLogsService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.network_management| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-network_management library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
299 300 301 302 303 |
# File 'lib/google/cloud/network_management.rb', line 299 def self.configure yield ::Google::Cloud.configure.network_management if block_given? ::Google::Cloud.configure.network_management end |
.organization_vpc_flow_logs_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for OrganizationVpcFlowLogsService.
By default, this returns an instance of
Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the OrganizationVpcFlowLogsService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the OrganizationVpcFlowLogsService service. You can determine whether the method will succeed by calling organization_vpc_flow_logs_service_available?.
About OrganizationVpcFlowLogsService
The VPC Flow Logs organization service in the Google Cloud Network Management API provides organization level configurations that generate Flow Logs. The service and the configuration resources created using this service are global.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/google/cloud/network_management.rb', line 227 def self.organization_vpc_flow_logs_service version: :v1, transport: :grpc, &block require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::NetworkManagement.const_get(package_name).const_get(:OrganizationVpcFlowLogsService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.organization_vpc_flow_logs_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the OrganizationVpcFlowLogsService service is supported by the current client. If true, you can retrieve a client object by calling organization_vpc_flow_logs_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the OrganizationVpcFlowLogsService service, or if the versioned client gem needs an update to support the OrganizationVpcFlowLogsService service.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/google/cloud/network_management.rb', line 251 def self.organization_vpc_flow_logs_service_available? version: :v1, transport: :grpc require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::NetworkManagement.const_get package_name return false unless service_module.const_defined? :OrganizationVpcFlowLogsService service_module = service_module.const_get :OrganizationVpcFlowLogsService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.reachability_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ReachabilityService.
By default, this returns an instance of
Google::Cloud::NetworkManagement::V1::ReachabilityService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ReachabilityService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ReachabilityService service. You can determine whether the method will succeed by calling reachability_service_available?.
About ReachabilityService
The Reachability service in the Google Cloud Network Management API provides services that analyze the reachability within a single Google Virtual Private Cloud (VPC) network, between peered VPC networks, between VPC and on-premises networks, or between VPC networks and internet hosts. A reachability analysis is based on Google Cloud network configurations.
You can use the analysis results to verify these configurations and to troubleshoot connectivity issues.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/cloud/network_management.rb', line 82 def self.reachability_service version: :v1, transport: :grpc, &block require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::NetworkManagement.const_get(package_name).const_get(:ReachabilityService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.reachability_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ReachabilityService service is supported by the current client. If true, you can retrieve a client object by calling reachability_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ReachabilityService service, or if the versioned client gem needs an update to support the ReachabilityService service.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/google/cloud/network_management.rb', line 106 def self.reachability_service_available? version: :v1, transport: :grpc require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::NetworkManagement.const_get package_name return false unless service_module.const_defined? :ReachabilityService service_module = service_module.const_get :ReachabilityService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.vpc_flow_logs_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for VpcFlowLogsService.
By default, this returns an instance of
Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the VpcFlowLogsService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the VpcFlowLogsService service. You can determine whether the method will succeed by calling vpc_flow_logs_service_available?.
About VpcFlowLogsService
The VPC Flow Logs service in the Google Cloud Network Management API provides configurations that generate Flow Logs. The service and the configuration resources created using this service are global.
154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/google/cloud/network_management.rb', line 154 def self.vpc_flow_logs_service version: :v1, transport: :grpc, &block require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::NetworkManagement.const_get(package_name).const_get(:VpcFlowLogsService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.vpc_flow_logs_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the VpcFlowLogsService service is supported by the current client. If true, you can retrieve a client object by calling vpc_flow_logs_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the VpcFlowLogsService service, or if the versioned client gem needs an update to support the VpcFlowLogsService service.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/cloud/network_management.rb', line 178 def self.vpc_flow_logs_service_available? version: :v1, transport: :grpc require "google/cloud/network_management/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::NetworkManagement.const_get package_name return false unless service_module.const_defined? :VpcFlowLogsService service_module = service_module.const_get :VpcFlowLogsService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |